#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

BTRFSC_MNT_DIR=$(create_temp_workdir)
BTRFSC_TEST_FILE="${WORKDIR}/btrfsc-test.img"

_create_fs() {
    dd if=/dev/zero of="${BTRFSC_TEST_FILE}" count=1024 bs=1M
    mkdir -p "${BTRFSC_MNT_DIR}"
    mkfs.btrfs "${BTRFSC_TEST_FILE}"
    modprobe loop || /bin/true
    mount -t btrfs "${BTRFSC_TEST_FILE}" "${BTRFSC_MNT_DIR}"
}

# Need root to make subvolumes
check_have_root

_run_cmd _create_fs

setup_success

###########
# Execute #
###########

_umount_fs() {
    umount "${BTRFSC_TEST_FILE}"
}

check_pristine_fs() {
    "${BTRFSC_LIB_DIR}/check-pristine-fs" "${BTRFSC_MNT_DIR}"
}

test_set_default_subvolume() {
    "${BTRFSC_LIB_DIR}/test-set-default-subvolume" "${BTRFSC_MNT_DIR}"
}

test_initial_upgrade() {
    "${BTRFSC_LIB_DIR}/test-initial-upgrade" "${BTRFSC_MNT_DIR}"
}

test_second_upgrade() {
    "${BTRFSC_LIB_DIR}/test-second-upgrade" "${BTRFSC_MNT_DIR}"
}

trap "_umount_fs; test_failure" ERR
trap "_umount_fs" EXIT

# These tests must all be run sequentially.
# Each depends on the state left behind by the previous test.
src_test_pass <<-EOF
check_pristine_fs
test_set_default_subvolume
test_initial_upgrade
test_second_upgrade
EOF

_umount_fs
test_success
