#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

setup_success

###########
# Execute #
###########
test_grilo_playlist_browsing() {
    set -e
    local i pos ret=0 count=0 playlist_entries=()
    local tempdir=$(create_temp_workdir)
    local playlist="Generic_Sounds.pls"
    local browsed_files_log="${WORKDIR}/browsed-files.log"
    local expected_files_log="${WORKDIR}/expected-files.log"

    # Copy data to be indexed because we need a specific subset of it
    src_copy "${MEDIA_RESOURCE_DIR}/playlists/${playlist}" "${tempdir}"
    src_copy "${MEDIA_RESOURCE_DIR}/audio/" "${tempdir}"

    grep File "${tempdir}/${playlist}" | cut -d '=' -f 2- > "${expected_files_log}"
    "${TESTLIBDIR}/grilo-filesystem-browse-pls" "${tempdir}/${playlist}" | sed -n "s|\s\+URL: file://${tempdir}/\(.*\)|\1|p" > "${browsed_files_log}"

    # Sync logs to disk
    sync
    # Race condition in file syncing. Pfft.
    _sleep 3
    diff -u "${expected_files_log}" "${browsed_files_log}" || return 1
}

trap "test_failure" ERR

src_test_pass <<-EOF
test_grilo_playlist_browsing
EOF

test_success
