#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

setup_success

###########
# Execute #
###########
test_notifications_on_metadata_changes() {
    "${TESTLIBDIR}/grilo-metadata-changes-notify" $(create_temp_workdir)
}

test_grilo_filesystem_browser() {
    set -e
    local browsed_files_log="${WORKDIR}/browsed-files.log"
    local expected_files_log="${WORKDIR}/expected-files.log"
    local tempdir=$(create_temp_workdir)

    # Compare expected media browsing results with actual results
    find "${MEDIA_RESOURCE_DIR}" \
        -regex '\(.+\.jpg\|.+\.png\|.+\.oga\|.+\.mp3\|.+\.flac\|.+\.wav\|.+\.ogv\|.+\.pls\|.+\.m3u\)' \
        | sort > "${expected_files_log}"
    # FIXME: does not un-escape whitespace/special characters
    "${TESTLIBDIR}/grilo-filesystem-browse" "${RESOURCE_DIR}" | sed -n 's|\s\+URL: file://\(.*\)|\1|p' | sort > "${browsed_files_log}"
    # Sync logs to disk
    sync
    # Race condition in file syncing. Pfft.
    _sleep 3
    diff -u "${expected_files_log}" "${browsed_files_log}" || return 1
}

trap "test_failure" ERR

src_test_pass <<-EOF
test_notifications_on_metadata_changes
test_grilo_filesystem_browser
EOF

test_success
