#! /usr/bin/python3
# -*- coding: utf-8 -*-

# Copyright © 2015 Collabora Ltd.
#
# SPDX-License-Identifier: MPL-2.0
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

import unittest
import sys
import os

from gi.repository import GLib
from gi.repository import Gio

# import from parent directory
sys.path.insert(0, os.path.join(os.path.dirname(__file__), os.pardir))
from common import TrackerIndexer


class TestRemovableDevice(unittest.TestCase):
    def setUp(self):
        self.loop = GLib.MainLoop.new(None, False)
        self.monitor = Gio.VolumeMonitor.get()
        self.monitor.connect('mount-added', self.mount_added_cb)

    def tearDown(self):
        # Keep everything in place for further manual checks
        pass

    def mount_added_cb(self, monitor, mount):
        self.path = mount.get_root().get_path()
        self.loop.quit()

    def test_removable_device(self):
        print('Please insert storage ...')
        self.loop.run()

        # Copy our medias and start indexing
        self.indexer = TrackerIndexer()
        self.indexer.copy_medias(self.path)
        self.indexer.start()
        self.indexer.assert_all_indexed(self.path)

if __name__ == "__main__":
    unittest.main()
