#!/bin/bash
# vim: set sts=4 sw=4 et tw=0 :

set -e

TESTDIR=$(cd $(dirname $0); pwd; cd - &>/dev/null)
. "${TESTDIR}/config.sh"
. "${TESTDIR}/../../common/thumbnailer-utils.sh"

#########
# Setup #
#########
trap "setup_failure" ERR

set -x
# Need a DBus session for this test
ensure_dbus_session
set +x

setup_success

###########
# Execute #
###########
_launch_monitor() {
    # Launch tumblerd manually to allow LD_PRELOAD to work for 
    # chaiwala-apparmor-tumbler-tests
    pkill tumblerd || true
    /usr/lib/*-linux-gnu*/tumbler-1/tumblerd &
    TUMBLERD_PID=$!
    sleep 5
    # Launch and monitor the thumbnailer
    ${GDBUS} monitor --session --dest "${addr}" --object-path "${obj_path}" >"${logfile}" &
    GDBUS_MONITOR_PID=$!
}

_kill_monitor_return() {
    kill -s TERM $GDBUS_MONITOR_PID || true
    kill -s TERM $TUMBLERD_PID || true
    return $1
}

_generate_thumbnails() {
    set -x
    local i ret size files logfile addr obj_path method uris filetypes
    ret=0
    size=$1
    shift
    files=("$@")
    logfile="${WORKDIR}/monitor-tumblerd.log"
    addr="org.freedesktop.thumbnails.Thumbnailer1"
    obj_path="/org/freedesktop/thumbnails/Thumbnailer1"
    method="org.freedesktop.thumbnails.Thumbnailer1.Queue"
    uris=()
    filetypes=()

    for i in "${files[@]}"; do
        # Need path relative to /
        # FIXME: This doesn't do whitespace/special character escaping, etc
        uris+=("file://$i")
        filetypes+=($(file --mime-type "$i" | cut -d ":" -f 2 | tr -d ' '))
    done

    # Clear out old thumbnails.
    rm -rf ${HOME}/.cache/thumbnails/

    _launch_monitor

    # Files to thumbnail
    ${GDBUS} call --session --dest "${addr}" --object-path "${obj_path}" \
        --method "${method}" \
        "$(bash_arrays_to_gvariant_as "${uris[@]}")" \
        "$(bash_arrays_to_gvariant_as "${filetypes[@]}")" \
        "${size}" foreground 0

    # Wait for thumbnailing to finish
    # FIXME: Race condition! Fix me to loop on the monitor log file.
    _sleep 2
    _check_uris_have_thumbnail $size $uris || ret=1

    _kill_monitor_return $ret
    set +x
}

test_image_normal_thumbnail_generation() {
    _generate_thumbnails normal "${MEDIA_RESOURCE_DIR}/images"/*
}

test_image_large_thumbnail_generation() {
    _generate_thumbnails large "${MEDIA_RESOURCE_DIR}/images"/*
}

test_video_normal_thumbnail_generation() {
    _generate_thumbnails normal "${MEDIA_RESOURCE_DIR}/videos"/*
}

test_video_large_thumbnail_generation() {
    _generate_thumbnails large "${MEDIA_RESOURCE_DIR}/videos"/*
}

test_document_normal_thumbnail_generation() {
    _generate_thumbnails normal "${MEDIA_RESOURCE_DIR}/documents"/*.{pdf,odt}
}

test_document_large_thumbnail_generation() {
    _generate_thumbnails large "${MEDIA_RESOURCE_DIR}/documents"/*.{pdf,odt}
}

trap "test_failure" ERR

# NOTE: Tumbler cannot thumbnail audio files
src_test_pass <<-EOF
test_image_normal_thumbnail_generation
test_image_large_thumbnail_generation
test_document_normal_thumbnail_generation
test_document_large_thumbnail_generation
test_video_normal_thumbnail_generation
test_video_large_thumbnail_generation
EOF

test_success
